@@ -323,7 +323,7 @@ class TranslatableAdmin(ModelAdmin, TranslatableModelAdminMixin):
         for lang in FALLBACK_LANGUAGES:
             if not lang in languages:
                 languages.append(lang)
-        qs = self.model._default_manager.untranslated().use_fallbacks()
+        qs = self.model._default_manager.untranslated().use_fallbacks(*languages)
         # TODO: this should be handled by some parameter to the ChangeList.
         ordering = self.ordering or () # otherwise we might try to *None, which is bad ;)
         if ordering:
@@ -553,7 +553,7 @@ class TranslatableInlineModelAdmin(InlineModelAdmin, TranslatableModelAdminMixin
 
 
 class TranslatableStackedInline(TranslatableInlineModelAdmin):
-    template = 'admin/edit_inline/stacked.html'
+    template = 'admin/nani/edit_inline/stacked.html'
 
 class TranslatableTabularInline(TranslatableInlineModelAdmin):
     template = 'admin/nani/edit_inline/tabular.html'
\ No newline at end of file
